[evolution-data-server/mmeeks-gdbus-import] fix another set of g -> e conversions that were missing



commit b1cd5d32b828c26713a76026f0c14da8ec88a798
Author: Michael Meeks <michael meeks novell com>
Date:   Mon Mar 1 16:15:55 2010 +0000

    fix another set of g -> e conversions that were missing

 edbus/edbus-marshal.c         |   89 -----------------------------------------
 edbus/edbus-marshal.h         |   20 ---------
 edbus/edbusconnection.c       |   60 ++++++++++++++--------------
 edbus/edbusenums.h            |   30 +++++++-------
 edbus/edbusenumtypes.c        |   18 ++++----
 edbus/edbusenumtypes.h        |    8 ++--
 edbus/edbusmethodinvocation.c |    4 +-
 edbus/edbusnameowning.c       |    4 +-
 edbus/edbusnamewatching.c     |    4 +-
 edbus/edbusproxy.c            |   10 ++--
 edbus/edbusproxywatching.c    |    4 +-
 edbus/example-own-name.c      |    8 ++--
 edbus/example-server.c        |    4 +-
 edbus/example-subtree.c       |    4 +-
 edbus/example-watch-name.c    |    2 +-
 edbus/example-watch-proxy.c   |    2 +-
 edbus/tests/connection.c      |   18 ++++----
 edbus/tests/export.c          |    2 +-
 edbus/tests/introspection.c   |    2 +-
 edbus/tests/names.c           |   46 +++++++++++-----------
 edbus/tests/peer.c            |    2 +-
 edbus/tests/proxy.c           |    2 +-
 edbus/tests/threading.c       |    6 +-
 23 files changed, 120 insertions(+), 229 deletions(-)
---
diff --git a/edbus/edbusenumtypes.c b/edbus/edbusenumtypes.c
index 07e4a9d..f5a53ed 100644
--- a/edbus/edbusenumtypes.c
+++ b/edbus/edbusenumtypes.c
@@ -86,17 +86,17 @@ e_variant_flags_get_type (void)
 
 /* enumerations from "edbusenums.h" */
 GType
-g_bus_type_get_type (void)
+e_dbus_type_get_type (void)
 {
   static volatile gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
       static const GEnumValue values[] = {
-        { G_BUS_TYPE_NONE, "G_BUS_TYPE_NONE", "none" },
-        { G_BUS_TYPE_SESSION, "G_BUS_TYPE_SESSION", "session" },
-        { G_BUS_TYPE_SYSTEM, "G_BUS_TYPE_SYSTEM", "system" },
-        { G_BUS_TYPE_STARTER, "G_BUS_TYPE_STARTER", "starter" },
+        { E_BUS_TYPE_NONE, "E_BUS_TYPE_NONE", "none" },
+        { E_BUS_TYPE_SESSION, "E_BUS_TYPE_SESSION", "session" },
+        { E_BUS_TYPE_SYSTEM, "E_BUS_TYPE_SYSTEM", "system" },
+        { E_BUS_TYPE_STARTER, "E_BUS_TYPE_STARTER", "starter" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -108,16 +108,16 @@ g_bus_type_get_type (void)
 }
 
 GType
-g_bus_name_owner_flags_get_type (void)
+e_dbus_name_owner_flags_get_type (void)
 {
   static volatile gsize g_define_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_define_type_id__volatile))
     {
       static const GFlagsValue values[] = {
-        { G_BUS_NAME_OWNER_FLAGS_NONE, "G_BUS_NAME_OWNER_FLAGS_NONE", "none" },
-        { G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT, "G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT", "allow-replacement" },
-        { G_BUS_NAME_OWNER_FLAGS_REPLACE, "G_BUS_NAME_OWNER_FLAGS_REPLACE", "replace" },
+        { E_BUS_NAME_OWNER_FLAGS_NONE, "E_BUS_NAME_OWNER_FLAGS_NONE", "none" },
+        { E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT, "E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT", "allow-replacement" },
+        { E_BUS_NAME_OWNER_FLAGS_REPLACE, "E_BUS_NAME_OWNER_FLAGS_REPLACE", "replace" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
diff --git a/edbus/edbusenumtypes.h b/edbus/edbusenumtypes.h
index 03e5368..e908574 100644
--- a/edbus/edbusenumtypes.h
+++ b/edbus/edbusenumtypes.h
@@ -17,10 +17,10 @@ GType e_variant_flags_get_type (void) G_GNUC_CONST;
 #define E_TYPE_VARIANT_FLAGS (e_variant_flags_get_type ())
 
 /* enumerations from "edbusenums.h" */
-GType g_bus_type_get_type (void) G_GNUC_CONST;
-#define G_TYPE_BUS_TYPE (g_bus_type_get_type ())
-GType g_bus_name_owner_flags_get_type (void) G_GNUC_CONST;
-#define G_TYPE_BUS_NAME_OWNER_FLAGS (g_bus_name_owner_flags_get_type ())
+GType e_dbus_type_get_type (void) G_GNUC_CONST;
+#define E_TYPE_DBUS_TYPE (e_dbus_type_get_type ())
+GType e_dbus_name_owner_flags_get_type (void) G_GNUC_CONST;
+#define E_TYPE_DBUS_NAME_OWNER_FLAGS (e_dbus_name_owner_flags_get_type ())
 GType e_dbus_proxy_flags_get_type (void) G_GNUC_CONST;
 #define E_TYPE_DBUS_PROXY_FLAGS (e_dbus_proxy_flags_get_type ())
 GType e_dbus_error_get_type (void) G_GNUC_CONST;
diff --git a/edbus/edbusmethodinvocation.c b/edbus/edbusmethodinvocation.c
index 502dc87..253fcda 100644
--- a/edbus/edbusmethodinvocation.c
+++ b/edbus/edbusmethodinvocation.c
@@ -451,8 +451,8 @@ e_dbus_method_invocation_new (const gchar      *sender,
   g_return_val_if_fail (method_name != NULL, NULL);
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), NULL);
   g_return_val_if_fail (parameters != NULL, NULL);
-  g_return_val_if_fail ((e_dbus_connection_get_bus_type (connection) == G_BUS_TYPE_NONE && sender == NULL) ||
-                        (e_dbus_connection_get_bus_type (connection) != G_BUS_TYPE_NONE && sender != NULL), NULL);
+  g_return_val_if_fail ((e_dbus_connection_get_bus_type (connection) == E_BUS_TYPE_NONE && sender == NULL) ||
+                        (e_dbus_connection_get_bus_type (connection) != E_BUS_TYPE_NONE && sender != NULL), NULL);
 
   return E_DBUS_METHOD_INVOCATION (g_object_new (E_TYPE_DBUS_METHOD_INVOCATION,
                                                  "sender", sender,
diff --git a/edbus/edbusproxy.c b/edbus/edbusproxy.c
index 1811089..234e3e9 100644
--- a/edbus/edbusproxy.c
+++ b/edbus/edbusproxy.c
@@ -364,7 +364,7 @@ e_dbus_proxy_class_init (EDBusProxyClass *klass)
                                          G_STRUCT_OFFSET (EDBusProxyClass, signal),
                                          NULL,
                                          NULL,
-                                         _gdbus_marshal_VOID__STRING_STRING_BOXED,
+                                         _edbus_marshal_VOID__STRING_STRING_BOXED,
                                          G_TYPE_NONE,
                                          3,
                                          G_TYPE_STRING,
@@ -846,8 +846,8 @@ e_dbus_proxy_new (EDBusConnection     *connection,
   g_return_if_fail (G_IS_DBUS_CONNECTION (connection));
   g_return_if_fail (g_type_is_a (object_type, E_TYPE_DBUS_PROXY));
   /* TODO: check that unique_bus_name is unique */
-  g_return_if_fail ((e_dbus_connection_get_bus_type (connection) == G_BUS_TYPE_NONE && unique_bus_name == NULL) ||
-                    (e_dbus_connection_get_bus_type (connection) != G_BUS_TYPE_NONE || unique_bus_name != NULL));
+  g_return_if_fail ((e_dbus_connection_get_bus_type (connection) == E_BUS_TYPE_NONE && unique_bus_name == NULL) ||
+                    (e_dbus_connection_get_bus_type (connection) != E_BUS_TYPE_NONE || unique_bus_name != NULL));
   g_return_if_fail (object_path != NULL);
   g_return_if_fail (interface_name);
 
@@ -935,8 +935,8 @@ e_dbus_proxy_new_sync (EDBusConnection     *connection,
 
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), NULL);
   g_return_val_if_fail (g_type_is_a (object_type, E_TYPE_DBUS_PROXY), NULL);
-  g_return_val_if_fail ((e_dbus_connection_get_bus_type (connection) == G_BUS_TYPE_NONE && unique_bus_name == NULL) ||
-                        (e_dbus_connection_get_bus_type (connection) != G_BUS_TYPE_NONE || unique_bus_name != NULL),
+  g_return_val_if_fail ((e_dbus_connection_get_bus_type (connection) == E_BUS_TYPE_NONE && unique_bus_name == NULL) ||
+                        (e_dbus_connection_get_bus_type (connection) != E_BUS_TYPE_NONE || unique_bus_name != NULL),
                         NULL);
   g_return_val_if_fail (object_path != NULL, NULL);
   g_return_val_if_fail (interface_name, NULL);
diff --git a/edbus/example-own-name.c b/edbus/example-own-name.c
index 96c5325..1b87fff 100644
--- a/edbus/example-own-name.c
+++ b/edbus/example-own-name.c
@@ -54,13 +54,13 @@ main (int argc, char *argv[])
       return 1;
     }
 
-  flags = G_BUS_NAME_OWNER_FLAGS_NONE;
+  flags = E_BUS_NAME_OWNER_FLAGS_NONE;
   if (opt_replace)
-    flags |= G_BUS_NAME_OWNER_FLAGS_REPLACE;
+    flags |= E_BUS_NAME_OWNER_FLAGS_REPLACE;
   if (opt_allow_replacement)
-    flags |= G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT;
+    flags |= E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT;
 
-  owner_id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  owner_id = e_bus_own_name (E_BUS_TYPE_SESSION,
                              opt_name,
                              flags,
                              on_name_acquired,
diff --git a/edbus/example-server.c b/edbus/example-server.c
index db1a399..a37165c 100644
--- a/edbus/example-server.c
+++ b/edbus/example-server.c
@@ -301,9 +301,9 @@ main (int argc, char *argv[])
   introspection_data = e_dbus_node_info_new_for_xml (introspection_xml, NULL);
   g_assert (introspection_data != NULL);
 
-  owner_id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  owner_id = e_bus_own_name (E_BUS_TYPE_SESSION,
                              "org.gtk.EDBus.TestServer",
-                             G_BUS_NAME_OWNER_FLAGS_NONE,
+                             E_BUS_NAME_OWNER_FLAGS_NONE,
                              on_name_acquired,
                              on_name_lost,
                              NULL,
diff --git a/edbus/example-subtree.c b/edbus/example-subtree.c
index 5dc920f..baf8f84 100644
--- a/edbus/example-subtree.c
+++ b/edbus/example-subtree.c
@@ -369,9 +369,9 @@ main (int argc, char *argv[])
   g_assert (block_interface_info != NULL);
   g_assert (partition_interface_info != NULL);
 
-  owner_id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  owner_id = e_bus_own_name (E_BUS_TYPE_SESSION,
                              "org.gtk.EDBus.TestSubtree",
-                             G_BUS_NAME_OWNER_FLAGS_NONE,
+                             E_BUS_NAME_OWNER_FLAGS_NONE,
                              on_name_acquired,
                              on_name_lost,
                              NULL,
diff --git a/edbus/example-watch-name.c b/edbus/example-watch-name.c
index 940df79..79716d6 100644
--- a/edbus/example-watch-name.c
+++ b/edbus/example-watch-name.c
@@ -60,7 +60,7 @@ main (int argc, char *argv[])
       goto out;
     }
 
-  watcher_id = e_bus_watch_name (opt_system_bus ? G_BUS_TYPE_SYSTEM : G_BUS_TYPE_SESSION,
+  watcher_id = e_bus_watch_name (opt_system_bus ? E_BUS_TYPE_SYSTEM : E_BUS_TYPE_SESSION,
                                  opt_name,
                                  on_name_appeared,
                                  on_name_vanished,
diff --git a/edbus/example-watch-proxy.c b/edbus/example-watch-proxy.c
index 0a69a2d..e73c0dd 100644
--- a/edbus/example-watch-proxy.c
+++ b/edbus/example-watch-proxy.c
@@ -151,7 +151,7 @@ main (int argc, char *argv[])
       goto out;
     }
 
-  watcher_id = e_bus_watch_proxy (opt_system_bus ? G_BUS_TYPE_SYSTEM : G_BUS_TYPE_SESSION,
+  watcher_id = e_bus_watch_proxy (opt_system_bus ? E_BUS_TYPE_SYSTEM : E_BUS_TYPE_SESSION,
                                   opt_name,
                                   opt_object_path,
                                   opt_interface,
diff --git a/edbus/tests/connection.c b/edbus/tests/connection.c
index 709b575..4f4c3ce 100644
--- a/edbus/tests/connection.c
+++ b/edbus/tests/connection.c
@@ -45,7 +45,7 @@ test_connection_life_cycle (void)
    * Check for correct behavior when no bus is present
    *
    */
-  c = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  c = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_error (error, E_DBUS_ERROR, E_DBUS_ERROR_FILE_NOT_FOUND);
   g_assert (!e_dbus_error_is_remote_error (error));
   g_assert (c == NULL);
@@ -57,7 +57,7 @@ test_connection_life_cycle (void)
    */
   session_bus_up ();
   /* case 1 */
-  c = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  c = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_no_error (error);
   g_assert (c != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c));
@@ -65,7 +65,7 @@ test_connection_life_cycle (void)
   /**
    * Check that singleton handling work
    */
-  c2 = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  c2 = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_no_error (error);
   g_assert (c2 != NULL);
   g_assert (c == c2);
@@ -74,7 +74,7 @@ test_connection_life_cycle (void)
   /**
    * Check that private connections work
    */
-  c2 = e_dbus_connection_bus_get_private_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  c2 = e_dbus_connection_bus_get_private_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_no_error (error);
   g_assert (c2 != NULL);
   g_assert (c != c2);
@@ -184,7 +184,7 @@ test_connection_send (void)
   session_bus_up ();
 
   /* First, get an unopened connection */
-  c = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  c = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, NULL);
   g_assert (c != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c));
 
@@ -330,12 +330,12 @@ test_connection_signals (void)
    */
   if (g_getenv ("E_DBUS_MONITOR") == NULL)
     {
-      c1 = e_dbus_connection_bus_get_private_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+      c1 = e_dbus_connection_bus_get_private_sync (E_BUS_TYPE_SESSION, NULL, NULL);
       g_assert (c1 != NULL);
       g_assert (!e_dbus_connection_get_is_disconnected (c1));
       g_object_unref (c1);
     }
-  c1 = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  c1 = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, NULL);
   g_assert (c1 != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c1));
   g_assert_cmpstr (e_dbus_connection_get_unique_name (c1), ==, ":1.1");
@@ -386,11 +386,11 @@ test_connection_signals (void)
   /**
    * Bring up two other connections
    */
-  c2 = e_dbus_connection_bus_get_private_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  c2 = e_dbus_connection_bus_get_private_sync (E_BUS_TYPE_SESSION, NULL, NULL);
   g_assert (c2 != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c2));
   g_assert_cmpstr (e_dbus_connection_get_unique_name (c2), ==, ":1.2");
-  c3 = e_dbus_connection_bus_get_private_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  c3 = e_dbus_connection_bus_get_private_sync (E_BUS_TYPE_SESSION, NULL, NULL);
   g_assert (c3 != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c3));
   g_assert_cmpstr (e_dbus_connection_get_unique_name (c3), ==, ":1.3");
diff --git a/edbus/tests/export.c b/edbus/tests/export.c
index bb4c9ad..2c1e074 100644
--- a/edbus/tests/export.c
+++ b/edbus/tests/export.c
@@ -654,7 +654,7 @@ test_object_registration (void)
   num_successful_registrations = 0;
 
   error = NULL;
-  c = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  c = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_no_error (error);
   g_assert (c != NULL);
 
diff --git a/edbus/tests/introspection.c b/edbus/tests/introspection.c
index 388139c..24ad707 100644
--- a/edbus/tests/introspection.c
+++ b/edbus/tests/introspection.c
@@ -113,7 +113,7 @@ test_introspection_parser (void)
 
   session_bus_up ();
 
-  watcher_id = e_bus_watch_proxy (G_BUS_TYPE_SESSION,
+  watcher_id = e_bus_watch_proxy (E_BUS_TYPE_SESSION,
                                   "com.example.TestService",
                                   "/com/example/TestObject",
                                   "com.example.Frob",
diff --git a/edbus/tests/names.c b/edbus/tests/names.c
index e2e53ce..63c853c 100644
--- a/edbus/tests/names.c
+++ b/edbus/tests/names.c
@@ -104,9 +104,9 @@ test_bus_own_name (void)
   data.num_acquired = 0;
   data.num_lost = 0;
   data.expect_null_connection = TRUE;
-  id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  id = e_bus_own_name (E_BUS_TYPE_SESSION,
                        name,
-                       G_BUS_NAME_OWNER_FLAGS_NONE,
+                       E_BUS_NAME_OWNER_FLAGS_NONE,
                        name_acquired_handler,
                        name_lost_handler,
                        &data,
@@ -129,9 +129,9 @@ test_bus_own_name (void)
   data.num_acquired = 0;
   data.num_lost = 0;
   data.expect_null_connection = FALSE;
-  id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  id = e_bus_own_name (E_BUS_TYPE_SESSION,
                        name,
-                       G_BUS_NAME_OWNER_FLAGS_NONE,
+                       E_BUS_NAME_OWNER_FLAGS_NONE,
                        name_acquired_handler,
                        name_lost_handler,
                        &data,
@@ -145,7 +145,7 @@ test_bus_own_name (void)
   /**
    * Check that the name was actually acquired.
    */
-  c = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  c = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, NULL);
   g_assert (c != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c));
   result = e_dbus_connection_invoke_method_sync (c,
@@ -198,9 +198,9 @@ test_bus_own_name (void)
   data.num_acquired = 0;
   data.num_lost = 0;
   data.expect_null_connection = FALSE;
-  id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  id = e_bus_own_name (E_BUS_TYPE_SESSION,
                        name,
-                       G_BUS_NAME_OWNER_FLAGS_NONE,
+                       E_BUS_NAME_OWNER_FLAGS_NONE,
                        name_acquired_handler,
                        name_lost_handler,
                        &data,
@@ -219,9 +219,9 @@ test_bus_own_name (void)
   data2.num_acquired = 0;
   data2.num_lost = 0;
   data2.expect_null_connection = FALSE;
-  id2 = e_bus_own_name (G_BUS_TYPE_SESSION,
+  id2 = e_bus_own_name (E_BUS_TYPE_SESSION,
                         name,
-                        G_BUS_NAME_OWNER_FLAGS_NONE,
+                        E_BUS_NAME_OWNER_FLAGS_NONE,
                         name_acquired_handler,
                         name_lost_handler,
                         &data2,
@@ -242,7 +242,7 @@ test_bus_own_name (void)
    * connection. This should fail both with and without _REPLACE because we
    * didn't specify ALLOW_REPLACEMENT.
    */
-  c2 = e_dbus_connection_bus_get_private_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  c2 = e_dbus_connection_bus_get_private_sync (E_BUS_TYPE_SESSION, NULL, NULL);
   g_assert (c2 != NULL);
   g_assert (!e_dbus_connection_get_is_disconnected (c2));
   /* first without _REPLACE */
@@ -252,7 +252,7 @@ test_bus_own_name (void)
   data2.num_free_func = 0;
   id2 = e_bus_own_name_on_connection (c2,
                                       name,
-                                      G_BUS_NAME_OWNER_FLAGS_NONE,
+                                      E_BUS_NAME_OWNER_FLAGS_NONE,
                                       name_acquired_handler,
                                       name_lost_handler,
                                       &data2,
@@ -274,7 +274,7 @@ test_bus_own_name (void)
   data2.num_free_func = 0;
   id2 = e_bus_own_name_on_connection (c2,
                                       name,
-                                      G_BUS_NAME_OWNER_FLAGS_REPLACE,
+                                      E_BUS_NAME_OWNER_FLAGS_REPLACE,
                                       name_acquired_handler,
                                       name_lost_handler,
                                       &data2,
@@ -303,9 +303,9 @@ test_bus_own_name (void)
   data.num_acquired = 0;
   data.num_lost = 0;
   data.expect_null_connection = FALSE;
-  id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  id = e_bus_own_name (E_BUS_TYPE_SESSION,
                        name,
-                       G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT,
+                       E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT,
                        name_acquired_handler,
                        name_lost_handler,
                        &data,
@@ -327,7 +327,7 @@ test_bus_own_name (void)
   data2.num_free_func = 0;
   id2 = e_bus_own_name_on_connection (c2,
                                       name,
-                                      G_BUS_NAME_OWNER_FLAGS_NONE,
+                                      E_BUS_NAME_OWNER_FLAGS_NONE,
                                       name_acquired_handler,
                                       name_lost_handler,
                                       &data2,
@@ -350,7 +350,7 @@ test_bus_own_name (void)
   data2.num_free_func = 0;
   id2 = e_bus_own_name_on_connection (c2,
                                       name,
-                                      G_BUS_NAME_OWNER_FLAGS_REPLACE,
+                                      E_BUS_NAME_OWNER_FLAGS_REPLACE,
                                       name_acquired_handler,
                                       name_lost_handler,
                                       &data2,
@@ -489,7 +489,7 @@ test_bus_watch_name (void)
   data.num_appeared = 0;
   data.num_vanished = 0;
   data.expect_null_connection = TRUE;
-  id = e_bus_watch_name (G_BUS_TYPE_SESSION,
+  id = e_bus_watch_name (E_BUS_TYPE_SESSION,
                          "org.gtk.EDBus.Name1",
                          name_appeared_handler,
                          name_vanished_handler,
@@ -515,9 +515,9 @@ test_bus_watch_name (void)
   data.num_acquired = 0;
   data.num_lost = 0;
   data.expect_null_connection = FALSE;
-  owner_id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  owner_id = e_bus_own_name (E_BUS_TYPE_SESSION,
                              "org.gtk.EDBus.Name1",
-                             G_BUS_NAME_OWNER_FLAGS_NONE,
+                             E_BUS_NAME_OWNER_FLAGS_NONE,
                              w_name_acquired_handler,
                              w_name_lost_handler,
                              &data,
@@ -528,7 +528,7 @@ test_bus_watch_name (void)
   /* now watch the name */
   data.num_appeared = 0;
   data.num_vanished = 0;
-  id = e_bus_watch_name (G_BUS_TYPE_SESSION,
+  id = e_bus_watch_name (E_BUS_TYPE_SESSION,
                          "org.gtk.EDBus.Name1",
                          name_appeared_handler,
                          name_vanished_handler,
@@ -572,7 +572,7 @@ test_bus_watch_name (void)
   data.num_appeared = 0;
   data.num_vanished = 0;
   data.num_free_func = 0;
-  id = e_bus_watch_name (G_BUS_TYPE_SESSION,
+  id = e_bus_watch_name (E_BUS_TYPE_SESSION,
                          "org.gtk.EDBus.Name1",
                          name_appeared_handler,
                          name_vanished_handler,
@@ -588,9 +588,9 @@ test_bus_watch_name (void)
   data.num_acquired = 0;
   data.num_lost = 0;
   data.expect_null_connection = FALSE;
-  owner_id = e_bus_own_name (G_BUS_TYPE_SESSION,
+  owner_id = e_bus_own_name (E_BUS_TYPE_SESSION,
                              "org.gtk.EDBus.Name1",
-                             G_BUS_NAME_OWNER_FLAGS_NONE,
+                             E_BUS_NAME_OWNER_FLAGS_NONE,
                              w_name_acquired_handler,
                              w_name_lost_handler,
                              &data,
diff --git a/edbus/tests/peer.c b/edbus/tests/peer.c
index 3c2855e..8f7b9f5 100644
--- a/edbus/tests/peer.c
+++ b/edbus/tests/peer.c
@@ -305,7 +305,7 @@ test_peer (void)
   g_main_loop_run (loop);
   g_assert_cmpint (data.current_connections->len, ==, 1);
   g_assert_cmpint (data.num_connection_attempts, ==, 1);
-  g_assert (e_dbus_connection_get_bus_type (c) == G_BUS_TYPE_NONE);
+  g_assert (e_dbus_connection_get_bus_type (c) == E_BUS_TYPE_NONE);
   g_assert (e_dbus_connection_get_unique_name (c) == NULL);
   g_assert_cmpstr (e_dbus_connection_get_address (c), ==, test_address);
 
diff --git a/edbus/tests/proxy.c b/edbus/tests/proxy.c
index 575ce8d..ca3fc43 100644
--- a/edbus/tests/proxy.c
+++ b/edbus/tests/proxy.c
@@ -342,7 +342,7 @@ test_proxy (void)
    */
   usleep (500 * 1000);
 
-  watcher_id = e_bus_watch_proxy (G_BUS_TYPE_SESSION,
+  watcher_id = e_bus_watch_proxy (E_BUS_TYPE_SESSION,
                                   "com.example.TestService",
                                   "/com/example/TestObject",
                                   "com.example.Frob",
diff --git a/edbus/tests/threading.c b/edbus/tests/threading.c
index 82d5d3f..00e17d1 100644
--- a/edbus/tests/threading.c
+++ b/edbus/tests/threading.c
@@ -200,7 +200,7 @@ test_delivery_in_thread_func (gpointer _data)
   g_assert (subscription_id != 0);
   g_assert (data.signal_count == 0);
 
-  priv_c = e_dbus_connection_bus_get_private_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  priv_c = e_dbus_connection_bus_get_private_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_no_error (error);
   g_assert (priv_c != NULL);
 
@@ -457,7 +457,7 @@ test_method_calls_in_thread (void)
 {
   guint watcher_id;
 
-  watcher_id = e_bus_watch_proxy (G_BUS_TYPE_SESSION,
+  watcher_id = e_bus_watch_proxy (E_BUS_TYPE_SESSION,
                                   "com.example.TestService",
                                   "/com/example/TestObject",
                                   "com.example.Frob",
@@ -511,7 +511,7 @@ main (int   argc,
 
   /* Create the connection in the main thread */
   error = NULL;
-  c = e_dbus_connection_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  c = e_dbus_connection_bus_get_sync (E_BUS_TYPE_SESSION, NULL, &error);
   g_assert_no_error (error);
   g_assert (c != NULL);
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/edbus/edbusconnection.c b/edbus/edbusconnection.c
index 49af86c..a5c887b 100644
--- a/edbus/edbusconnection.c
+++ b/edbus/edbusconnection.c
@@ -281,12 +281,12 @@ e_dbus_connection_class_init (EDBusConnectionClass *klass)
    * EDBusConnection:bus-type:
    *
    * When constructing an object, set this to the type of the message bus
    * the connection is for or #G_BUS_TYPE_NONE if the connection is not
    * a message bus connection.
    *
    * When reading, this property is never #G_BUS_TYPE_STARTER - if #G_BUS_TYPE_STARTER
    * was passed as a construction property, then this property will be either #G_BUS_TYPE_SESSION
    * or #G_BUS_TYPE_SYSTEM depending on what message bus activated the process.
    *
    * This property must be unset on construction if
    * #EDBusConnection:address is set upon construction.
@@ -296,8 +296,8 @@ e_dbus_connection_class_init (EDBusConnectionClass *klass)
                                    g_param_spec_enum ("bus-type",
                                                       _("bus-type"),
                                                       _("The type of message bus, if any, the connection is for"),
-                                                      G_TYPE_BUS_TYPE,
-                                                      G_BUS_TYPE_NONE,
+                                                      E_TYPE_DBUS_TYPE,
+                                                      E_BUS_TYPE_NONE,
                                                       G_PARAM_READABLE |
                                                       G_PARAM_WRITABLE |
                                                       G_PARAM_CONSTRUCT_ONLY |
@@ -328,7 +328,7 @@ e_dbus_connection_class_init (EDBusConnectionClass *klass)
    * EDBusConnection:is-private:
    *
    * When constructing an object and #EDBusConnection:bus-type is set to something
    * other than #G_BUS_TYPE_NONE, specifies whether the connection to the requested
    * message bus should be a private connection.
    * This property is ignored if #EDBusConnection:dbus-1-connection is set upon construction.
    *
@@ -457,20 +457,20 @@ e_dbus_connection_init (EDBusConnection *connection)
  *
  * Gets the type of message bus connection, if any.
  *
  * This will never return #G_BUS_TYPE_STARTER. If
  * #G_BUS_TYPE_STARTER was passed to e_dbus_connection_bus_get()
  * then the return value will be either #G_BUS_TYPE_SESSION or
  * #G_BUS_TYPE_SYSTEM depending on what bus started the
  * process.
  *
  * Returns: Type type of the message bus the connection is for or
  * #G_BUS_TYPE_NONE if the connection is not to a message
  * bus.
  **/
 EDBusType
 e_dbus_connection_get_bus_type (EDBusConnection *connection)
 {
-  g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), G_BUS_TYPE_NONE);
+  g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), E_BUS_TYPE_NONE);
 
   return connection->priv->bus_type;
 }
@@ -714,33 +714,33 @@ e_dbus_connection_constructor (GType                  type,
           bus_type = g_value_get_enum (construct_properties[n].value);
           switch (bus_type)
             {
-            case G_BUS_TYPE_NONE:
+            case E_BUS_TYPE_NONE:
               /* do nothing */
               break;
 
-            case G_BUS_TYPE_SESSION:
+            case E_BUS_TYPE_SESSION:
               singleton = &the_session_bus;
               break;
 
-            case G_BUS_TYPE_SYSTEM:
+            case E_BUS_TYPE_SYSTEM:
               singleton = &the_system_bus;
               break;
 
-            case G_BUS_TYPE_STARTER:
+            case E_BUS_TYPE_STARTER:
               starter_bus = g_getenv ("DBUS_STARTER_BUS_TYPE");
               if (g_strcmp0 (starter_bus, "session") == 0)
                 {
-                  g_value_set_enum (construct_properties[n].value, G_BUS_TYPE_SESSION);
+                  g_value_set_enum (construct_properties[n].value, E_BUS_TYPE_SESSION);
                   singleton = &the_session_bus;
                 }
               else if (g_strcmp0 (starter_bus, "system") == 0)
                 {
-                  g_value_set_enum (construct_properties[n].value, G_BUS_TYPE_SYSTEM);
+                  g_value_set_enum (construct_properties[n].value, E_BUS_TYPE_SYSTEM);
                   singleton = &the_system_bus;
                 }
               else
                 {
-                  g_critical (_("Cannot construct a EDBusConnection object with bus_type G_BUS_TYPE_STARTER "
+                  g_critical (_("Cannot construct a EDBusConnection object with bus_type E_BUS_TYPE_STARTER "
                                 "because the DBUS_STARTER_BUS_TYPE environment variable is not set. "
                                 "This is an error in the application or library using EDBus."));
                   goto out;
@@ -817,7 +817,7 @@ initable_init (GInitable       *initable,
   dbus_error_init (&dbus_error);
   if (connection->priv->address != NULL)
     {
-      g_assert (connection->priv->bus_type == G_BUS_TYPE_NONE); /* API contract */
+      g_assert (connection->priv->bus_type == E_BUS_TYPE_NONE); /* API contract */
 
       if (connection->priv->is_private)
         {
@@ -832,7 +832,7 @@ initable_init (GInitable       *initable,
     }
   else
     {
-      g_assert (connection->priv->bus_type != G_BUS_TYPE_NONE); /* API contract */
+      g_assert (connection->priv->bus_type != E_BUS_TYPE_NONE); /* API contract */
       if (connection->priv->is_private)
         {
           dbus_1_connection = dbus_bus_get_private (connection->priv->bus_type,
@@ -1305,7 +1305,7 @@ e_dbus_connection_get_unique_name (EDBusConnection *connection)
 {
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), NULL);
 
-  if (connection->priv->bus_type == G_BUS_TYPE_NONE)
+  if (connection->priv->bus_type == E_BUS_TYPE_NONE)
     return NULL;
 
   if (connection->priv->dbus_1_connection != NULL)
@@ -1874,7 +1874,7 @@ e_dbus_connection_signal_subscribe (EDBusConnection     *connection,
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), 0);
   g_return_val_if_fail (!e_dbus_connection_get_is_disconnected (connection), 0);
   g_return_val_if_fail (sender == NULL || ((strcmp (sender, DBUS_SERVICE_DBUS) == 0 || sender[0] == ':') &&
-                                           connection->priv->bus_type != G_BUS_TYPE_NONE), 0);
+                                           connection->priv->bus_type != E_BUS_TYPE_NONE), 0);
   g_return_val_if_fail (callback != NULL, 0);
   /* TODO: check that passed in data is well-formed */
 
@@ -1921,7 +1921,7 @@ e_dbus_connection_signal_subscribe (EDBusConnection     *connection,
    * Avoid adding match rules for NameLost and NameAcquired messages - the bus will
    * always send such messages to to us.
    */
-  if (connection->priv->bus_type != G_BUS_TYPE_NONE)
+  if (connection->priv->bus_type != E_BUS_TYPE_NONE)
     {
       if (!is_signal_data_for_name_lost_or_acquired (signal_data))
         {
@@ -1996,7 +1996,7 @@ unsubscribe_id_internal (EDBusConnection    *connection,
           g_assert (g_hash_table_remove (connection->priv->map_sender_to_signal_data_array, signal_data->sender));
 
           /* remove the match rule from the bus unless NameLost or NameAcquired (see subscribe()) */
-          if (connection->priv->bus_type != G_BUS_TYPE_NONE)
+          if (connection->priv->bus_type != E_BUS_TYPE_NONE)
             {
               if (!is_signal_data_for_name_lost_or_acquired (signal_data))
                 {
@@ -3419,8 +3419,8 @@ e_dbus_connection_invoke_method (EDBusConnection    *connection,
   error = NULL;
 
   g_return_if_fail (G_IS_DBUS_CONNECTION (connection));
-  g_return_if_fail ((connection->priv->bus_type == G_BUS_TYPE_NONE && bus_name == NULL) ||
-                    (connection->priv->bus_type != G_BUS_TYPE_NONE && bus_name != NULL));
+  g_return_if_fail ((connection->priv->bus_type == E_BUS_TYPE_NONE && bus_name == NULL) ||
+                    (connection->priv->bus_type != E_BUS_TYPE_NONE && bus_name != NULL));
   g_return_if_fail (object_path != NULL);
   g_return_if_fail (interface_name != NULL);
   g_return_if_fail (method_name != NULL);
@@ -3565,8 +3565,8 @@ e_dbus_connection_invoke_method_sync (EDBusConnection    *connection,
   result = NULL;
 
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), NULL);
-  g_return_val_if_fail ((connection->priv->bus_type == G_BUS_TYPE_NONE && bus_name == NULL) ||
-                        (connection->priv->bus_type != G_BUS_TYPE_NONE && bus_name != NULL),
+  g_return_val_if_fail ((connection->priv->bus_type == E_BUS_TYPE_NONE && bus_name == NULL) ||
+                        (connection->priv->bus_type != E_BUS_TYPE_NONE && bus_name != NULL),
                         NULL);
   g_return_val_if_fail (object_path != NULL, NULL);
   g_return_val_if_fail (interface_name != NULL, NULL);
@@ -281,12 +281,12 @@ e_dbus_connection_class_init (EDBusConnectionClass *klass)
    *
    * When constructing an object, set this to the type of the message bus
-   * the connection is for or #G_BUS_TYPE_NONE if the connection is not
+   * the connection is for or #E_BUS_TYPE_NONE if the connection is not
    * a message bus connection.
    *
@@ -281,12 +281,12 @@ e_dbus_connection_class_init (EDBusConnectionClass *klass)
    * a message bus connection.
    *
-   * When reading, this property is never #G_BUS_TYPE_STARTER - if #G_BUS_TYPE_STARTER
-   * was passed as a construction property, then this property will be either #G_BUS_TYPE_SESSION
-   * or #G_BUS_TYPE_SYSTEM depending on what message bus activated the process.
+   * When reading, this property is never #E_BUS_TYPE_STARTER - if #E_BUS_TYPE_STARTER
+   * was passed as a construction property, then this property will be either #E_BUS_TYPE_SESSION
+   * or #E_BUS_TYPE_SYSTEM depending on what message bus activated the process.
    *
    * This property must be unset on construction if
@@ -328,7 +328,7 @@ e_dbus_connection_class_init (EDBusConnectionClass *klass)
    *
    * When constructing an object and #EDBusConnection:bus-type is set to something
-   * other than #G_BUS_TYPE_NONE, specifies whether the connection to the requested
+   * other than #E_BUS_TYPE_NONE, specifies whether the connection to the requested
    * message bus should be a private connection.
    * This property is ignored if #EDBusConnection:dbus-1-connection is set upon construction.
@@ -457,20 +457,20 @@ e_dbus_connection_init (EDBusConnection *connection)
  * Gets the type of message bus connection, if any.
  *
- * This will never return #G_BUS_TYPE_STARTER. If
- * #G_BUS_TYPE_STARTER was passed to e_dbus_connection_bus_get()
- * then the return value will be either #G_BUS_TYPE_SESSION or
- * #G_BUS_TYPE_SYSTEM depending on what bus started the
+ * This will never return #E_BUS_TYPE_STARTER. If
+ * #E_BUS_TYPE_STARTER was passed to e_dbus_connection_bus_get()
+ * then the return value will be either #E_BUS_TYPE_SESSION or
+ * #E_BUS_TYPE_SYSTEM depending on what bus started the
  * process.
  *
@@ -457,20 +457,20 @@ e_dbus_connection_init (EDBusConnection *connection)
  *
  * Returns: Type type of the message bus the connection is for or
- * #G_BUS_TYPE_NONE if the connection is not to a message
+ * #E_BUS_TYPE_NONE if the connection is not to a message
  * bus.
  **/
diff --git a/edbus/edbusenums.h b/edbus/edbusenums.h
index d9a50c8..7b59180 100644
--- a/edbus/edbusenums.h
+++ b/edbus/edbusenums.h
@@ -34,36 +34,36 @@ G_BEGIN_DECLS
 
 /**
  * EDBusType:
  * @G_BUS_TYPE_NONE: Not a message bus connection.
  * @G_BUS_TYPE_SESSION: The login session message bus.
  * @G_BUS_TYPE_SYSTEM: The system-wide message bus.
  * @G_BUS_TYPE_STARTER: Connect to the bus that activated the program.
  *
  * An enumeration to specify the type of a #EDBusConnection.
  */
 typedef enum
 {
-  G_BUS_TYPE_NONE    = -1,
-  G_BUS_TYPE_SESSION = 0,
-  G_BUS_TYPE_SYSTEM  = 1,
-  G_BUS_TYPE_STARTER = 2
+  E_BUS_TYPE_NONE    = -1,
+  E_BUS_TYPE_SESSION = 0,
+  E_BUS_TYPE_SYSTEM  = 1,
+  E_BUS_TYPE_STARTER = 2
 } EDBusType;
 
 /**
  * EDBusNameOwnerFlags:
  * @G_BUS_NAME_OWNER_FLAGS_NONE: No flags set.
  * @G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT: Allow another message connection to take the name.
  * @G_BUS_NAME_OWNER_FLAGS_REPLACE: If another message bus connection
  * owns the name and have specified #G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT, then
  * take the name from the other connection.
  *
  * Flags used when constructing a #GBusNameOwner.
  */
 typedef enum
 {
-  G_BUS_NAME_OWNER_FLAGS_NONE = 0,                    /*< nick=none >*/
-  G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT = (1<<0),  /*< nick=allow-replacement >*/
-  G_BUS_NAME_OWNER_FLAGS_REPLACE = (1<<1),            /*< nick=replace >*/
+  E_BUS_NAME_OWNER_FLAGS_NONE = 0,                    /*< nick=none >*/
+  E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT = (1<<0),  /*< nick=allow-replacement >*/
+  E_BUS_NAME_OWNER_FLAGS_REPLACE = (1<<1),            /*< nick=replace >*/
 } EDBusNameOwnerFlags;
 
 /**
@@ -34,36 +34,36 @@ G_BEGIN_DECLS
 /**
  * EDBusType:
- * @G_BUS_TYPE_NONE: Not a message bus connection.
- * @G_BUS_TYPE_SESSION: The login session message bus.
- * @G_BUS_TYPE_SYSTEM: The system-wide message bus.
- * @G_BUS_TYPE_STARTER: Connect to the bus that activated the program.
+ * @E_BUS_TYPE_NONE: Not a message bus connection.
+ * @E_BUS_TYPE_SESSION: The login session message bus.
+ * @E_BUS_TYPE_SYSTEM: The system-wide message bus.
+ * @E_BUS_TYPE_STARTER: Connect to the bus that activated the program.
  *
  * An enumeration to specify the type of a #EDBusConnection.
@@ -34,36 +34,36 @@ G_BEGIN_DECLS
 /**
  * EDBusNameOwnerFlags:
- * @G_BUS_NAME_OWNER_FLAGS_NONE: No flags set.
- * @G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT: Allow another message connection to take the name.
- * @G_BUS_NAME_OWNER_FLAGS_REPLACE: If another message bus connection
- * owns the name and have specified #G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT, then
+ * @E_BUS_NAME_OWNER_FLAGS_NONE: No flags set.
+ * @E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT: Allow another message connection to take the name.
+ * @E_BUS_NAME_OWNER_FLAGS_REPLACE: If another message bus connection
+ * owns the name and have specified #E_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT, then
  * take the name from the other connection.
  *
diff --git a/edbus/edbusnameowning.c b/edbus/edbusnameowning.c
index ec995a2..086fdbe 100644
--- a/edbus/edbusnameowning.c
+++ b/edbus/edbusnameowning.c
@@ -493,7 +493,7 @@ e_bus_own_name_on_connection (EDBusConnection          *connection,
 
 /**
  * e_bus_own_name:
  * @bus_type: The type of bus to own a name on (can't be #G_BUS_TYPE_NONE).
  * @name: The well-known name to own.
  * @flags: A set of flags from the #EDBusNameOwnerFlags enumeration.
  * @name_acquired_handler: Handler to invoke when @name is acquired.
@@ -546,7 +546,7 @@ e_bus_own_name (EDBusType                  bus_type,
 {
   Client *client;
 
-  g_return_val_if_fail (bus_type != G_BUS_TYPE_NONE, 0);
+  g_return_val_if_fail (bus_type != E_BUS_TYPE_NONE, 0);
   g_return_val_if_fail (name != NULL, 0);
   //g_return_val_if_fail (TODO_is_well_known_name (), 0);
   g_return_val_if_fail (name_acquired_handler != NULL, 0);
@@ -493,7 +493,7 @@ e_bus_own_name_on_connection (EDBusConnection          *connection,
 /**
  * e_bus_own_name:
- * @bus_type: The type of bus to own a name on (can't be #G_BUS_TYPE_NONE).
+ * @bus_type: The type of bus to own a name on (can't be #E_BUS_TYPE_NONE).
  * @name: The well-known name to own.
  * @flags: A set of flags from the #EDBusNameOwnerFlags enumeration.
diff --git a/edbus/edbusnamewatching.c b/edbus/edbusnamewatching.c
index b51df55..835c9a3 100644
--- a/edbus/edbusnamewatching.c
+++ b/edbus/edbusnamewatching.c
@@ -410,7 +410,7 @@ connection_get_cb (GObject      *source_object,
 
 /**
  * e_bus_watch_name:
  * @bus_type: The type of bus to watch a name on (can't be #G_BUS_TYPE_NONE).
  * @name: The name (well-known or unique) to watch.
  * @name_appeared_handler: Handler to invoke when @name is known to exist.
  * @name_vanished_handler: Handler to invoke when @name is known to not exist.
@@ -460,7 +460,7 @@ e_bus_watch_name (EDBusType                  bus_type,
 {
   Client *client;
 
-  g_return_val_if_fail (bus_type != G_BUS_TYPE_NONE, 0);
+  g_return_val_if_fail (bus_type != E_BUS_TYPE_NONE, 0);
   g_return_val_if_fail (name != NULL, 0);
   g_return_val_if_fail (name_appeared_handler != NULL, 0);
   g_return_val_if_fail (name_vanished_handler != NULL, 0);
@@ -410,7 +410,7 @@ connection_get_cb (GObject      *source_object,
 /**
  * e_bus_watch_name:
- * @bus_type: The type of bus to watch a name on (can't be #G_BUS_TYPE_NONE).
+ * @bus_type: The type of bus to watch a name on (can't be #E_BUS_TYPE_NONE).
  * @name: The name (well-known or unique) to watch.
  * @name_appeared_handler: Handler to invoke when @name is known to exist.
diff --git a/edbus/edbusproxywatching.c b/edbus/edbusproxywatching.c
index 8271fb5..32c00ad 100644
--- a/edbus/edbusproxywatching.c
+++ b/edbus/edbusproxywatching.c
@@ -283,7 +283,7 @@ on_name_vanished (EDBusConnection *connection,
 
 /**
  * e_bus_watch_proxy:
  * @bus_type: The type of bus to watch a name on (can't be #G_BUS_TYPE_NONE).
  * @name: The name (well-known or unique) to watch.
  * @object_path: The object path of the remote object to watch.
  * @interface_name: The D-Bus interface name for the proxy.
@@ -342,7 +342,7 @@ e_bus_watch_proxy (EDBusType                   bus_type,
 {
   Client *client;
 
-  g_return_val_if_fail (bus_type != G_BUS_TYPE_NONE, 0);
+  g_return_val_if_fail (bus_type != E_BUS_TYPE_NONE, 0);
   g_return_val_if_fail (name != NULL, 0);
   g_return_val_if_fail (proxy_appeared_handler != NULL, 0);
   g_return_val_if_fail (proxy_vanished_handler != NULL, 0);
@@ -283,7 +283,7 @@ on_name_vanished (EDBusConnection *connection,
 /**
  * e_bus_watch_proxy:
- * @bus_type: The type of bus to watch a name on (can't be #G_BUS_TYPE_NONE).
+ * @bus_type: The type of bus to watch a name on (can't be #E_BUS_TYPE_NONE).
  * @name: The name (well-known or unique) to watch.
  * @object_path: The object path of the remote object to watch.